==> uweb-cli-1.3.0.tgz: package/template/gulpfile.js <==
var gulp = require('gulp');
var htmltpl = require('gulp-html-tpl');
var del = require('del');
var artTemplate = require('art-template');
var watch = require('gulp-watch');
var sass = require('gulp-sass');
var concat = require('gulp-concat');
var uglify = require('gulp-uglify');
var cleanCSS = require('gulp-clean-css');
var rename = require("gulp-rename");
var cache = require("gulp-cache");
var connect = require('gulp-connect');
var sourcemaps = require('gulp-sourcemaps');
var postcss = require('gulp-postcss');
var autoprefixer = require('autoprefixer');
var babel = require('gulp-babel');
var eslint = require('gulp-eslint');
var stylelint = require('gulp-stylelint');
var log = require("fancy-log");
const os = require('os');
const net = require('net');

var Paths = {
    src: {
        static: "src/static/",
        script: "src/script/",
        scriptLib: "src/script/libs/*.js",
        cssLib: "src/style/libs/*.css",
        css: "src/style/",
        views: "src/views/**/*",
        font: "src/font/",
        media: "src/media/",
        images: "src/images/",
        data: "src/data/"
    },
    built: {
        root: "built/",
        script: "built/script/",
        css: "built/style/",
        static: "built/static/",
        font: "built/font/",
        media: "built/media/",
        images: "built/images/",
        data: "built/data/"
    }
};

const ipAddress = getIpAddress()
let serverPort = 9000,
    liveLoadPort = 35729
// task src
function delhtml () {
    return del([
        'src/static/**/*'
    ]);
}
exports.delhtml = delhtml

function showIp () {
    log(`服务运行在: http://${ipAddress}:${serverPort}`)
}

var compileHtml = gulp.series(delhtml, function () {
    showIp()
    return gulp.src(Paths.src.views)
        .pipe(cache(htmltpl({
            tag: 'template',
            engine: function (template, data) {
                return artTemplate.compile(template)(data)
            },
            beautify: {
                indent_size: 4,
                indent_char: ' ',
                indent_with_tabs: false,
                eol: '\n'
            }
        })))
        .pipe(gulp.dest(Paths.src.static))
        .pipe(connect.reload())
})
exports.compileHtml = compileHtml

function lintcss () {
    return gulp.src(Paths.src.css + '**/*.scss')
        .pipe(cache(stylelint({
            reporters: [{
                formatter: 'string',
                console: true
            }]
        })))
}

var sassCompile = gulp.series(lintcss, function () {
    showIp()
    return gulp.src(Paths.src.css + 'style.scss')
        .pipe(sourcemaps.init())
        .pipe(sass({
            outputStyle: 'compressed'
        }).on('error', sass.logError))
        .pipe(sourcemaps.write('./maps'))
        .pipe(gulp.dest(Paths.src.css));
})
exports.sassCompile = sassCompile

var prefixer = gulp.series(sassCompile, function () {
    return gulp.src(Paths.src.css + 'style.css')
        .pipe(cache(sourcemaps.init()))
        .pipe(postcss([autoprefixer()]))
        .pipe(sourcemaps.write('./maps'))
        .pipe(gulp.dest(Paths.src.css))
        .pipe(connect.reload());
})
exports.prefixer = prefixer

function scriptmin () {
    return gulp.src(Paths.src.scriptLib)
        .pipe(concat('core.js'))
        .pipe(uglify())
        .pipe(gulp.dest(Paths.src.script));
}
exports.scriptmin = scriptmin

function cssmin () {
    return gulp.src(Paths.src.cssLib)
        .pipe(concat('core.css'))
        .pipe(cleanCSS())
        .pipe(gulp.dest(Paths.src.css));
}
exports.cssmin = cssmin

function jseslint () {
    return gulp.src(Paths.src.script + 'es6/*.js')
        .pipe(cache(eslint()))
        .pipe(eslint.format())
        .pipe(eslint.failAfterError());
}
exports.jseslint = jseslint

var scriptbabel = gulp.series(jseslint, function () {
    showIp()
    return gulp.src(Paths.src.script + 'es6/*.js')
        .pipe(cache(babel({
            presets: ['@babel/env']
        })))
        .pipe(uglify())
        .pipe(gulp.dest(Paths.src.script));
})
exports.scriptbabel = scriptbabel

function getIpAddress () {
    var ifaces = os.networkInterfaces()
    for (var dev in ifaces) {
        let iface = ifaces[dev]
        for (let i = 0; i < iface.length; i++) {
            let {family, address, internal} = iface[i]
            if (family === 'IPv4' && address !== '127.0.0.1' && !internal) {
                return address
            }
        }
    }
}

// 检查端口是否被占用
function checkPort (port) {
    return new Promise((resolve, reject) => {
        const server = net.createServer().listen(port)
        server.on('error', (err) => {
            if (err.code === 'EADDRINUSE') {
                resolve(false) // 端口被占用
            } else {
                reject(err) // 其他错误
            }
        })
        server.on('listening', () => {
            server.close(() => {
                resolve(true) // 端口未被占用
            })
        })
    })
}

async function getAvailablePort (port) {
    let available = await checkPort(port)
    while (!available) {
        port++
        serverPort++
        available = await checkPort(port)
    }
    return port
}

function connectServer () {
    getAvailablePort(liveLoadPort).then((port) => {
        connect.server({
            livereload: {
                port: port
            },
            port: serverPort,
            host: '0.0.0.0'
        });
        console.log(`服务已经运行，http://${ipAddress}:${serverPort} 或 http://localhost:${serverPort}`)
    })
}
exports.connectServer = connectServer


var watchTask = gulp.parallel(connectServer, function () {
    gulp.watch(Paths.src.views, compileHtml)
    gulp.watch(Paths.src.css + '**/*.scss', prefixer);
    gulp.watch(Paths.src.scriptLib, scriptmin);
    gulp.watch(Paths.src.cssLib, cssmin);
    gulp.watch(Paths.src.script + 'es6/*.js', scriptbabel);
})
exports.default = watchTask

==> uweb-cli-1.3.2.tgz: package/template/gulpfile.js <==
var gulp = require('gulp');
var htmltpl = require('gulp-html-tpl');
var del = require('del');
var artTemplate = require('art-template');
var watch = require('gulp-watch');
var sass = require('gulp-sass');
var concat = require('gulp-concat');
var uglify = require('gulp-uglify');
var cleanCSS = require('gulp-clean-css');
var rename = require("gulp-rename");
var changed = require('gulp-changed');
var changedInPlace = require('gulp-changed-in-place');
var connect = require('gulp-connect');
var sourcemaps = require('gulp-sourcemaps');
var postcss = require('gulp-postcss');
var autoprefixer = require('autoprefixer');
var babel = require('gulp-babel');
var eslint = require('gulp-eslint');
var stylelint = require('gulp-stylelint');
var log = require("fancy-log");
const os = require('os');
const net = require('net');

var Paths = {
    src: {
        static: "src/static/",
        script: "src/script/",
        scriptLib: "src/script/libs/*.js",
        cssLib: "src/style/libs/*.css",
        css: "src/style/",
        views: "src/views/**/*",
        public: "src/views/public/**/*",
        watchViews: "src/views//*",
        font: "src/font/",
        media: "src/media/",
        images: "src/images/",
        data: "src/data/"
    },
    built: {
        root: "built/",
        script: "built/script/",
        css: "built/style/",
        static: "built/static/",
        font: "built/font/",
        media: "built/media/",
        images: "built/images/",
        data: "built/data/"
    }
};

const ipAddress = getIpAddress()
let serverPort = 9000,
    liveLoadPort = 35729
// task src
function delhtml () {
    return del([
        'src/static/**/*'
    ]);
}
exports.delhtml = delhtml

function showIp () {
    log(`服务运行在: http://${ipAddress}:${serverPort}`)
}

var compileHtml = gulp.series(function () {
    showIp()
    return gulp.src(Paths.src.views)
        .pipe(changed(Paths.src.static))
        .pipe(htmltpl({
            tag: 'template',
            engine: function (template, data) {
                return artTemplate.compile(template)(data)
            },
            beautify: {
                indent_size: 4,
                indent_char: ' ',
                indent_with_tabs: false,
                eol: '\n'
            }
        }))
        .pipe(gulp.dest(Paths.src.static))
        .pipe(connect.reload())
})
exports.compileHtml = compileHtml

var compileAllHtml = gulp.series(function () {
    showIp()
    return gulp.src(Paths.src.views)
        .pipe(htmltpl({
            tag: 'template',
            engine: function (template, data) {
                return artTemplate.compile(template)(data)
            },
            beautify: {
                indent_size: 4,
                indent_char: ' ',
                indent_with_tabs: false,
                eol: '\n'
            }
        }))
        .pipe(gulp.dest(Paths.src.static))
        .pipe(connect.reload())
})
exports.compileAllHtml = compileAllHtml

function lintcss () {
    return gulp.src(Paths.src.css + '**/*.scss')
        .pipe(changedInPlace())
        .pipe(stylelint({
            reporters: [{
                formatter: 'string',
                console: true
            }]
        }))
}

var sassCompile = gulp.series(lintcss, function () {
    showIp()
    return gulp.src(Paths.src.css + 'style.scss')
        .pipe(sourcemaps.init())
        .pipe(sass({
            outputStyle: 'compressed'
        }).on('error', sass.logError))
        .pipe(sourcemaps.write('./maps'))
        .pipe(gulp.dest(Paths.src.css));
})
exports.sassCompile = sassCompile

var prefixer = gulp.series(sassCompile, function () {
    return gulp.src(Paths.src.css + 'style.css')
        .pipe(sourcemaps.init())
        .pipe(postcss([autoprefixer()]))
        .pipe(sourcemaps.write('./maps'))
        .pipe(gulp.dest(Paths.src.css))
        .pipe(connect.reload());
})
exports.prefixer = prefixer

function scriptmin () {
    return gulp.src(Paths.src.scriptLib)
        .pipe(concat('core.js'))
        .pipe(uglify())
        .pipe(gulp.dest(Paths.src.script));
}
exports.scriptmin = scriptmin

function cssmin () {
    return gulp.src(Paths.src.cssLib)
        .pipe(concat('core.css'))
        .pipe(cleanCSS())
        .pipe(gulp.dest(Paths.src.css));
}
exports.cssmin = cssmin

function jseslint () {
    return gulp.src(Paths.src.script + 'es6/*.js')
        .pipe(eslint())
        .pipe(eslint.format())
        .pipe(eslint.failAfterError());
}
exports.jseslint = jseslint

var scriptbabel = gulp.series(jseslint, function () {
    showIp()
    return gulp.src(Paths.src.script + 'es6/*.js')
        .pipe(changed(Paths.src.script))
        .pipe(babel({
            presets: ['@babel/env']
        }))
        .pipe(uglify())
        .pipe(gulp.dest(Paths.src.script))
        .pipe(connect.reload());
})
exports.scriptbabel = scriptbabel

function getIpAddress () {
    var ifaces = os.networkInterfaces()
    for (var dev in ifaces) {
        let iface = ifaces[dev]
        for (let i = 0; i < iface.length; i++) {
            let {family, address, internal} = iface[i]
            if (family === 'IPv4' && address !== '127.0.0.1' && !internal) {
                return address
            }
        }
    }
}

// 检查端口是否被占用
function checkPort (port) {
    return new Promise((resolve, reject) => {
        const server = net.createServer().listen(port)
        server.on('error', (err) => {
            if (err.code === 'EADDRINUSE') {
                resolve(false) // 端口被占用
            } else {
                reject(err) // 其他错误
            }
        })
        server.on('listening', () => {
            server.close(() => {
                resolve(true) // 端口未被占用
            })
        })
    })
}

async function getAvailablePort (port) {
    let available = await checkPort(port)
    while (!available) {
        port++
        serverPort++
        available = await checkPort(port)
    }
    return port
}

function connectServer () {
    getAvailablePort(liveLoadPort).then((port) => {
        connect.server({
            livereload: {
                port: port
            },
            port: serverPort,
            host: '0.0.0.0'
        });
        console.log(`服务已经运行，http://${ipAddress}:${serverPort} 或 http://localhost:${serverPort}`)
    })
}
exports.connectServer = connectServer

var watchTask = gulp.parallel(connectServer, function () {
    gulp.watch([Paths.src.views, "!src/views/public/**/*"], compileHtml)
    gulp.watch(Paths.src.public, compileAllHtml)
    gulp.watch(Paths.src.css + '**/*.scss', prefixer);
    gulp.watch(Paths.src.scriptLib, scriptmin);
    gulp.watch(Paths.src.cssLib, cssmin);
    gulp.watch(Paths.src.script + 'es6/*.js', scriptbabel);
})
exports.default = watchTask
